﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Configuration;
using TV4Home.Server.TVEInteractionLibrary;

namespace TV4Home.WebInterface.UI.Code
{
    /// <summary>
    /// Contains settings for the website. The settings are stored in the TVE database.
    /// </summary>
    public static class WebsiteSettings
    {
        #region Fields
        private static readonly TVEInteraction _tve = TVEInteraction.Instance;

        // database setting key names
        private const string SETTING_SHOWCHANNELNAMEIFCHANNELPICTUREISPRESENT = "TV4Home_WebInterface_ShowChannelNameIfChannelPictureIsPresent";
        private const string SETTING_TVGUIDEHOURSTOSHOW = "TV4Home_WebInterface_TVGuideHoursToShow";
        private const string SETTING_WEBSERVICEACCESSCODE = "TV4Home_WebInterface_WebServiceAccessCode";
        #endregion

        #region Properties
        public static bool ShowChannelNameIfChannelPictureIsPresent
        {
            get
            {
                // set default value
                if (String.IsNullOrEmpty(_tve.ReadSettingFromDatabase(SETTING_SHOWCHANNELNAMEIFCHANNELPICTUREISPRESENT)))
                    ShowChannelNameIfChannelPictureIsPresent = false;

                return Convert.ToBoolean(_tve.ReadSettingFromDatabase(SETTING_SHOWCHANNELNAMEIFCHANNELPICTUREISPRESENT));
            }
            set
            {
                _tve.WriteSettingToDatabase(SETTING_SHOWCHANNELNAMEIFCHANNELPICTUREISPRESENT, Convert.ToString(value));
            }
        }

        public static int TVGuideHoursToShow
        {
            get
            {
                // set default value
                if (String.IsNullOrEmpty(_tve.ReadSettingFromDatabase(SETTING_TVGUIDEHOURSTOSHOW)))
                    TVGuideHoursToShow = 3;

                return Convert.ToInt32(_tve.ReadSettingFromDatabase(SETTING_TVGUIDEHOURSTOSHOW));
            }
            set
            {
                _tve.WriteSettingToDatabase(SETTING_TVGUIDEHOURSTOSHOW, Convert.ToString(value));
            }
        }

        public static string WebServiceAccessCode
        {
            get
            {
                // set default value
                if (String.IsNullOrEmpty(_tve.ReadSettingFromDatabase(SETTING_WEBSERVICEACCESSCODE)))
                    WebServiceAccessCode = CreateRandomAccessCode(15);

                return _tve.ReadSettingFromDatabase(SETTING_WEBSERVICEACCESSCODE);
            }
            set
            {
                _tve.WriteSettingToDatabase(SETTING_WEBSERVICEACCESSCODE, value);
            }
        }
        #endregion

        #region Private Methods
        private static string CreateRandomAccessCode(int length)
        {
            Random rnd = new Random();

            const string numbers = "0123456789";
            const string lowercase = "abcdefghijklmnopqrstuvwxyz";
            const string uppercase = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
            const string special = "$?&=!%#";
            const string combinedChars = numbers + lowercase + special + uppercase;

            string code = "";

            for (int i = 0; i < length; i++)
            {
                code += combinedChars[rnd.Next(combinedChars.Length - 1)];
            }

            return code;
        }
        #endregion
    }
}
